# frozen_string_literal: true

require 'colorize'
require 'pry'

class WeatherByDcq::View
  attr_accessor :location, :forecast

  def menu
    puts ''
    puts 'Please enter a city to retrieve a forecast (Format: City State):'
    input_location = gets.strip
    location = input_location.gsub(/[\W\d]/, '').downcase

    puts "You entered: #{location}".colorize(:blue) + ' Is this correct (Y/N)?'
    input_confirm = gets.strip.downcase
    if input_confirm == 'n'
      puts 'I am sorry, let us try again.'
      menu
    elsif input_confirm == 'y'
      system('cls') || system('clear')
      puts ''
      puts "Current Conditions for #{location}:".colorize(:blue)
      puts '====================================='
      WeatherByDcq::Forecast.display_curr_table(location)

      # Extended forecast List
      puts 'Extended forecast:'.colorize(:blue)
      puts '--------------------'
      WeatherByDcq::Forecast.display_forecast_list
      puts ''
      options_menu
    else
      begin
        raise WeatherError
      rescue WeatherError => e
        puts e.message
      end
      menu
    end
  end

  def options_menu
    puts ''
    puts 'Would you like additional details about any of the days listed?'.colorize(:blue)
    puts 'Please enter the corresponding number for your request, or any letter to EXIT: '.colorize(:blue)
    detail_input = gets.strip.to_i
    if detail_input.positive? && detail_input < 9
      system('cls') || system('clear')
      WeatherByDcq::Forecast.display_details(detail_input)
      options_menu

    elsif detail_input.negative? || detail_input > 8
      begin
        raise WeatherError
      rescue WeatherError => e
        puts e.message
      end
      options_menu
    else
      exit
    end
  end

  class WeatherError < StandardError
    def message
      puts ''
      puts '    <== ERROR ==>'.colorize(:white).on_red
      puts ''
      puts ' I do not understand your response, please try again.'.colorize(:yellow)
    end
  end
end
